==> openshift-model-miscellaneous-6.8.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigStorageIBMCOSFluent.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ImageRegistryConfigStorageIBMCOSFluent<A extends ImageRegistryConfigStorageIBMCOSFluent<A>> extends BaseFluent<A>{
  public ImageRegistryConfigStorageIBMCOSFluent() {
  }
  public ImageRegistryConfigStorageIBMCOSFluent(ImageRegistryConfigStorageIBMCOS instance) {
    instance = (instance != null ? instance : new ImageRegistryConfigStorageIBMCOS());

    if (instance != null) {
      this.withBucket(instance.getBucket());
      this.withLocation(instance.getLocation());
      this.withResourceGroupName(instance.getResourceGroupName());
      this.withResourceKeyCRN(instance.getResourceKeyCRN());
      this.withServiceInstanceCRN(instance.getServiceInstanceCRN());
      this.withBucket(instance.getBucket());
      this.withLocation(instance.getLocation());
      this.withResourceGroupName(instance.getResourceGroupName());
      this.withResourceKeyCRN(instance.getResourceKeyCRN());
      this.withServiceInstanceCRN(instance.getServiceInstanceCRN());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String bucket;
  private String location;
  private String resourceGroupName;
  private String resourceKeyCRN;
  private String serviceInstanceCRN;
  private Map<String,Object> additionalProperties;
  public String getBucket() {
    return this.bucket;
  }
  public A withBucket(String bucket) {
    this.bucket=bucket; return (A) this;
  }
  public boolean hasBucket() {
    return this.bucket != null;
  }
  public String getLocation() {
    return this.location;
  }
  public A withLocation(String location) {
    this.location=location; return (A) this;
  }
  public boolean hasLocation() {
    return this.location != null;
  }
  public String getResourceGroupName() {
    return this.resourceGroupName;
  }
  public A withResourceGroupName(String resourceGroupName) {
    this.resourceGroupName=resourceGroupName; return (A) this;
  }
  public boolean hasResourceGroupName() {
    return this.resourceGroupName != null;
  }
  public String getResourceKeyCRN() {
    return this.resourceKeyCRN;
  }
  public A withResourceKeyCRN(String resourceKeyCRN) {
    this.resourceKeyCRN=resourceKeyCRN; return (A) this;
  }
  public boolean hasResourceKeyCRN() {
    return this.resourceKeyCRN != null;
  }
  public String getServiceInstanceCRN() {
    return this.serviceInstanceCRN;
  }
  public A withServiceInstanceCRN(String serviceInstanceCRN) {
    this.serviceInstanceCRN=serviceInstanceCRN; return (A) this;
  }
  public boolean hasServiceInstanceCRN() {
    return this.serviceInstanceCRN != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageRegistryConfigStorageIBMCOSFluent that = (ImageRegistryConfigStorageIBMCOSFluent) o;
    if (!java.util.Objects.equals(bucket, that.bucket)) return false;

    if (!java.util.Objects.equals(location, that.location)) return false;

    if (!java.util.Objects.equals(resourceGroupName, that.resourceGroupName)) return false;

    if (!java.util.Objects.equals(resourceKeyCRN, that.resourceKeyCRN)) return false;

    if (!java.util.Objects.equals(serviceInstanceCRN, that.serviceInstanceCRN)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(bucket,  location,  resourceGroupName,  resourceKeyCRN,  serviceInstanceCRN,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (bucket != null) { sb.append("bucket:"); sb.append(bucket + ","); }
    if (location != null) { sb.append("location:"); sb.append(location + ","); }
    if (resourceGroupName != null) { sb.append("resourceGroupName:"); sb.append(resourceGroupName + ","); }
    if (resourceKeyCRN != null) { sb.append("resourceKeyCRN:"); sb.append(resourceKeyCRN + ","); }
    if (serviceInstanceCRN != null) { sb.append("serviceInstanceCRN:"); sb.append(serviceInstanceCRN + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-miscellaneous-6.9.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigStorageIBMCOSFluent.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ImageRegistryConfigStorageIBMCOSFluent<A extends ImageRegistryConfigStorageIBMCOSFluent<A>> extends BaseFluent<A>{
  public ImageRegistryConfigStorageIBMCOSFluent() {
  }
  
  public ImageRegistryConfigStorageIBMCOSFluent(ImageRegistryConfigStorageIBMCOS instance) {
    this.copyInstance(instance);
  }
  private String bucket;
  private String location;
  private String resourceGroupName;
  private String resourceKeyCRN;
  private String serviceInstanceCRN;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ImageRegistryConfigStorageIBMCOS instance) {
    instance = (instance != null ? instance : new ImageRegistryConfigStorageIBMCOS());
  
    if (instance != null) {
        this.withBucket(instance.getBucket());
        this.withLocation(instance.getLocation());
        this.withResourceGroupName(instance.getResourceGroupName());
        this.withResourceKeyCRN(instance.getResourceKeyCRN());
        this.withServiceInstanceCRN(instance.getServiceInstanceCRN());
        this.withBucket(instance.getBucket());
        this.withLocation(instance.getLocation());
        this.withResourceGroupName(instance.getResourceGroupName());
        this.withResourceKeyCRN(instance.getResourceKeyCRN());
        this.withServiceInstanceCRN(instance.getServiceInstanceCRN());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getBucket() {
    return this.bucket;
  }
  
  public A withBucket(String bucket) {
    this.bucket=bucket; return (A) this;
  }
  
  public boolean hasBucket() {
    return this.bucket != null;
  }
  
  public String getLocation() {
    return this.location;
  }
  
  public A withLocation(String location) {
    this.location=location; return (A) this;
  }
  
  public boolean hasLocation() {
    return this.location != null;
  }
  
  public String getResourceGroupName() {
    return this.resourceGroupName;
  }
  
  public A withResourceGroupName(String resourceGroupName) {
    this.resourceGroupName=resourceGroupName; return (A) this;
  }
  
  public boolean hasResourceGroupName() {
    return this.resourceGroupName != null;
  }
  
  public String getResourceKeyCRN() {
    return this.resourceKeyCRN;
  }
  
  public A withResourceKeyCRN(String resourceKeyCRN) {
    this.resourceKeyCRN=resourceKeyCRN; return (A) this;
  }
  
  public boolean hasResourceKeyCRN() {
    return this.resourceKeyCRN != null;
  }
  
  public String getServiceInstanceCRN() {
    return this.serviceInstanceCRN;
  }
  
  public A withServiceInstanceCRN(String serviceInstanceCRN) {
    this.serviceInstanceCRN=serviceInstanceCRN; return (A) this;
  }
  
  public boolean hasServiceInstanceCRN() {
    return this.serviceInstanceCRN != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageRegistryConfigStorageIBMCOSFluent that = (ImageRegistryConfigStorageIBMCOSFluent) o;
    if (!java.util.Objects.equals(bucket, that.bucket)) return false;
  
    if (!java.util.Objects.equals(location, that.location)) return false;
  
    if (!java.util.Objects.equals(resourceGroupName, that.resourceGroupName)) return false;
  
    if (!java.util.Objects.equals(resourceKeyCRN, that.resourceKeyCRN)) return false;
  
    if (!java.util.Objects.equals(serviceInstanceCRN, that.serviceInstanceCRN)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(bucket,  location,  resourceGroupName,  resourceKeyCRN,  serviceInstanceCRN,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (bucket != null) { sb.append("bucket:"); sb.append(bucket + ","); }
    if (location != null) { sb.append("location:"); sb.append(location + ","); }
    if (resourceGroupName != null) { sb.append("resourceGroupName:"); sb.append(resourceGroupName + ","); }
    if (resourceKeyCRN != null) { sb.append("resourceKeyCRN:"); sb.append(resourceKeyCRN + ","); }
    if (serviceInstanceCRN != null) { sb.append("serviceInstanceCRN:"); sb.append(serviceInstanceCRN + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
